@@ -1,5 +1,4 @@
 import json
-import os
 import pathlib
 import typing
 
@@ -25,7 +24,7 @@ special_delimiters = {
 @app.command(name="template")
 def template(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    name: str = typer.Argument(..., help="Data Product name", callback=util.sanitize),
     filepath: str = typer.Option(..., "--filepath", "-f", help="Filepath of the csv template", callback=util.sanitize),
     output_dir: str = typer.Option(
         ...,
@@ -72,10 +71,10 @@ def template(
         json.dump(r.json(), f, indent=4)
 
 
-@app.command(name="create-stored")
-def create_stored(
+@app.command(name="create")
+def create(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    name: str = typer.Argument(..., help="Data Product name", callback=util.sanitize),
     description: typing.Optional[str] = typer.Option(
         None,
         "--description",
@@ -83,96 +82,41 @@ def create_stored(
         help="Data Product description",
         callback=util.sanitize,
     ),
-    filepath: typing.Optional[str] = typer.Option(
-        None,
+    filepath: str = typer.Option(
+        ...,
         "--filepath",
         "-f",
-        help="Filepath of the table schema json payload",
+        help="Filepath of the details json payload",
         callback=util.sanitize,
     ),
 ) -> None:
-    """Create a stored data product."""
+    """Create a data product."""
 
     @ensure_login
-    def _request(ctx: typer.Context, dpc: schema.CreateStoredDataProduct) -> httpx.Response:
+    def _request(ctx: typer.Context, dpc: schema.CreateDataProduct) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_product_url(ctx)}/{name}",
+            f"{_product_url(ctx)}",
             json=dpc.dict(exclude_none=True, by_alias=True),
         )
 
-    fields = None
-    if filepath:
-        fp = util.get_file_location(filepath)
-        fields = util.load_fields_file(fp)
+    fp = util.get_file_location(filepath)
+    details = util.load_object_file(fp, "details")
 
-    dpc = schema.CreateStoredDataProduct(
+    dpc = schema.CreateDataProduct(
         name=name,
         description=description or "",
-        details=schema.StoredSchemaBase(
-            type="stored",
-            fields=fields,
-        ),
+        details=details,  # type: ignore[reportGeneralTypeIssues]
     )
 
     r = _request(ctx, dpc)
     process_response(r)
 
 
-@app.command(name="create-streaming")
-def create_streaming(
+@app.command(name="add-schema")
+def add_schema(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
-    description: typing.Optional[str] = typer.Option(
-        None,
-        "--description",
-        "-d",
-        help="Data Product description",
-        callback=util.sanitize,
-    ),
-    flow_type: str = typer.Option(..., "--flow-type", "-t", help="Flow type", callback=util.sanitize),
-    filepath: typing.Optional[str] = typer.Option(
-        None,
-        "--filepath",
-        "-f",
-        help="Filepath of the table schema json payload",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Create a streaming data product."""
-
-    @ensure_login
-    def _request(ctx: typer.Context, dpc: schema.CreateStreamingDataProduct) -> httpx.Response:
-        return util.post(
-            ctx,
-            f"{_product_url(ctx)}/{name}",
-            json=dpc.dict(exclude_none=True, by_alias=True),
-        )
-
-    fields = None
-    if filepath:
-        fp = util.get_file_location(filepath)
-        fields = util.load_fields_file(fp)
-
-    dpc = schema.CreateStreamingDataProduct(
-        name=name,
-        description=description or "",
-        details=schema.CreateStreamingSchema(
-            type="streaming",
-            fields=fields,
-            flow_type=flow_type,
-        ),
-    )
-    # TODO: support iceberg properties and orc bloom
-
-    r = _request(ctx, dpc)
-    process_response(r)
-
-
-@app.command(name="add-schema-stored")
-def add_schema_stored(
-    ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier", callback=util.sanitize),
     filepath: str = typer.Option(
         ...,
         "--filepath",
@@ -184,98 +128,22 @@ def add_schema_stored(
     """Add a schema to a stored data product."""
 
     @ensure_login
-    def _request(ctx: typer.Context, dps: schema.UpdateStoredSchema) -> httpx.Response:
+    def _request(ctx: typer.Context, dps: schema.UpdateDataProductSchema) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_product_url(ctx)}/{name}/schema",
+            f"{_product_url(ctx)}/{product_identifier}/schema",
             json=dps.dict(exclude_none=True, by_alias=True),
         )
 
     fp = util.get_file_location(filepath)
-    fields = util.load_fields_file(fp)
+    details = util.load_object_file(fp, "details")
 
-    dps = schema.UpdateStoredSchema(details=schema.StoredDataProductSchema(type="stored", fields=fields))
+    dps = schema.UpdateDataProductSchema(details=details)  # type: ignore[reportGeneralTypeIssues]
 
     r = _request(ctx, dps)
     process_response(r)
 
 
-@app.command(name="add-schema-streaming")
-def add_schema_streaming(
-    ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
-    filepath: str = typer.Option(
-        ...,
-        "--filepath",
-        "-f",
-        help="Filepath of the table schema json payload",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Add a schema to a streaming data product."""
-
-    @ensure_login
-    def _request(ctx: typer.Context, dps: schema.UpdateStreamingSchema) -> httpx.Response:
-        return util.post(
-            ctx,
-            f"{_product_url(ctx)}/{name}",
-            json=dps.dict(exclude_none=True, by_alias=True),
-        )
-
-    fp = util.get_file_location(filepath)
-    fields = util.load_fields_file(fp)
-
-    dps = schema.UpdateStreamingSchema(details=schema.StreamingDataProductSchema(type="streaming", fields=fields))
-    # TODO: support iceberg properties and orc bloom
-
-    r = _request(ctx, dps)
-    process_response(r)
-
-
-@app.command(name="create-subset")
-def create_subset(
-    ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
-    description: typing.Optional[str] = typer.Option(
-        None,
-        "--description",
-        "-d",
-        help="Data Product description",
-        callback=util.sanitize,
-    ),
-    parent: str = typer.Option(..., "--parent", "-p", help="Data product parent", callback=util.sanitize),
-    columns: typing.List[str] = typer.Option(
-        ...,
-        "--column",
-        "-c",
-        help="Parent column(s) to include",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Create a subset data product."""
-
-    @ensure_login
-    def _request(ctx: typer.Context, dpc: schema.CreateSubsetDataProduct) -> httpx.Response:
-        return util.post(
-            ctx,
-            f"{_product_url(ctx)}/{name}",
-            json=dpc.dict(exclude_none=True, by_alias=True),
-        )
-
-    dpc = schema.CreateSubsetDataProduct(
-        name=name,
-        description=description or "",
-        details=schema.SubsetSchema(
-            type="subset",
-            parent_product=parent,
-            columns=columns,
-        ),
-    )
-
-    r = _request(ctx, dpc)
-    process_response(r)
-
-
 @app.command(name="list")
 def list_products(ctx: typer.Context) -> None:
     """List data products."""
@@ -291,7 +159,7 @@ def list_products(ctx: typer.Context) -> None:
 @app.command()
 def delete_data(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier", callback=util.sanitize),
 ) -> None:
     """Delete data from a data product."""
 
@@ -299,7 +167,7 @@ def delete_data(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_product_url(ctx)}/{name}/data",
+            f"{_product_url(ctx)}/{product_identifier}/data",
         )
 
     r = _request(ctx)
@@ -309,7 +177,7 @@ def delete_data(
 @app.command()
 def delete(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier", callback=util.sanitize),
     *,
     force: bool = typer.Option(
         False,
@@ -323,7 +191,7 @@ def delete(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_product_url(ctx)}/{name}",
+            f"{_product_url(ctx)}/{product_identifier}",
             params={"force": force},
         )
 
@@ -334,7 +202,7 @@ def delete(
 @app.command()
 def publish(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier", callback=util.sanitize),
 ) -> None:
     """Publish a data product."""
 
@@ -342,7 +210,7 @@ def publish(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_product_url(ctx)}/{name}/publish",
+            f"{_product_url(ctx)}/{product_identifier}/publish",
         )
 
     r = _request(ctx)
@@ -352,7 +220,7 @@ def publish(
 @app.command()
 def unpublish(
     ctx: typer.Context,
-    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name", callback=util.sanitize),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier", callback=util.sanitize),
 ) -> None:
     """Unpublish a product."""
 
@@ -360,7 +228,7 @@ def unpublish(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_product_url(ctx)}/{name}/publish",
+            f"{_product_url(ctx)}/{product_identifier}/publish",
         )
 
     r = _request(ctx)
@@ -370,9 +238,9 @@ def unpublish(
 @app.command(name="get")
 def get_product(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -382,7 +250,7 @@ def get_product(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            f"{_product_url(ctx)}/{product_name}",
+            f"{_product_url(ctx)}/{product_identifier}",
         )
 
     r = _request(ctx)
@@ -392,9 +260,9 @@ def get_product(
 @app.command()
 def preview(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -409,7 +277,7 @@ def preview(
             ctx,
             "{product_url}/{name}/data".format(
                 product_url=_product_url(ctx),
-                name=product_name,
+                name=product_identifier,
             ),
         )
 
