@@ -4,8 +4,8 @@ import typing
 import click
 import typer
 
-from neosctl import schema
-from neosctl.util import get_user_profile_section, prettify_json, remove_config, send_output, upsert_config
+from neosctl import schema, util
+from neosctl.util import exit_with_output, get_user_profile_section, prettify_json, remove_config, upsert_config
 
 app = typer.Typer()
 
@@ -13,7 +13,8 @@ app = typer.Typer()
 r = re.compile(r"http[s]?:\/\/.*")
 
 
-def validate_url(value):
+def _validate_url(value: str) -> str:
+    """Validate a given url is a valid url with schema."""
     m = r.match(value)
     if m is None:
         msg = f"Invalid url, must match pattern: `{r}`."
@@ -24,12 +25,13 @@ def validate_url(value):
 @app.command()
 def init(
     ctx: typer.Context,
-    hostname: typing.Optional[str] = typer.Option(None, "--host", "-h"),
-    gateway_api_url: typing.Optional[str] = typer.Option(None, "--gateway-api-url", "-g"),
-    registry_api_url: typing.Optional[str] = typer.Option(None, "--registry-api-url", "-r"),
-    iam_api_url: typing.Optional[str] = typer.Option(None, "--iam-api-url", "-i"),
-    storage_api_url: typing.Optional[str] = typer.Option(None, "--storage-api-url", "-s"),
-    username: typing.Optional[str] = typer.Option(None, "--username", "-u"),
+    *,
+    hostname: typing.Optional[str] = typer.Option(None, "--host", "-h", callback=util.sanitize),
+    gateway_api_url: typing.Optional[str] = typer.Option(None, "--gateway-api-url", "-g", callback=util.sanitize),
+    registry_api_url: typing.Optional[str] = typer.Option(None, "--registry-api-url", "-r", callback=util.sanitize),
+    iam_api_url: typing.Optional[str] = typer.Option(None, "--iam-api-url", "-i", callback=util.sanitize),
+    storage_api_url: typing.Optional[str] = typer.Option(None, "--storage-api-url", "-s", callback=util.sanitize),
+    username: typing.Optional[str] = typer.Option(None, "--username", "-u", callback=util.sanitize),
     ignore_tls: bool = typer.Option(
         False,
         "--ignore-tls",
@@ -40,7 +42,7 @@ def init(
         "--non-interactive",
         help="Don't ask for input, generate api values based on hostname.",
     ),
-):
+) -> None:
     """Initialise a profile.
 
     Create a profile that can be reused in later commands to define which
@@ -52,7 +54,7 @@ def init(
     default_host = f"{hostname}/api/{{}}" if hostname else ""
 
     if non_interactive and not (hostname and username):
-        send_output(
+        raise exit_with_output(
             msg="\nError: --hostname/-h and --username/-u required for non-interactive mode.",
             exit_code=1,
         )
@@ -76,23 +78,25 @@ def init(
         ("storage", ctx.obj.get_storage_api_url(), "Storage API url"),
     ]:
         url_key = f"{key}_api_url"
-        if urls[url_key] is None:
+        url = urls[url_key]
+        if url is None:
             urls[url_key] = typer.prompt(
                 prompt,
                 default=default or default_host.format(key),
-                value_proc=validate_url,
+                value_proc=_validate_url,
             )
         else:
-            validate_url(urls[url_key])
+            _validate_url(url)
 
     if username is None:
         kwargs = {}
         if ctx.obj.profile:
             kwargs["default"] = ctx.obj.profile.user
-        username = typer.prompt(
+        username_input: str = typer.prompt(
             "Username",
             **kwargs,
         )
+        username = username_input
 
     profile = schema.Profile(  # nosec: B106
         user=username,
@@ -108,7 +112,7 @@ def init(
 @app.command()
 def delete(
     ctx: typer.Context,
-):
+) -> None:
     """Delete a profile."""
     typer.confirm(f"Remove [{ctx.obj.profile_name}] profile", abort=True)
     remove_config(ctx)
@@ -117,18 +121,19 @@ def delete(
 @app.command()
 def view(
     ctx: typer.Context,
-):
+) -> None:
     """View configuration for a profile."""
-    send_output(
-        msg=prettify_json({**get_user_profile_section(ctx.obj.config, ctx.obj.profile_name)}),
+    profile = get_user_profile_section(ctx.obj.config, ctx.obj.profile_name)
+    raise exit_with_output(
+        msg=prettify_json({k: v for k, v in profile.items()}),
     )
 
 
 @app.command(name="list")
 def list_profiles(
     ctx: typer.Context,
-):
+) -> None:
     """List available profiles."""
-    send_output(
+    raise exit_with_output(
         msg=prettify_json(sorted(ctx.obj.config.sections())),
     )
