@@ -68,6 +68,12 @@ class CreateStoredDataProduct(pydantic.BaseModel):
     details: StoredSchemaBase
 
 
+class CreateDataProduct(pydantic.BaseModel):
+    name: str
+    description: str
+    details: Union[StoredSchemaBase, CreateStreamingSchema, SubsetSchema] = pydantic.Field(..., discriminator="type")
+
+
 class StreamingDataProductSchema(StreamingSchemaBase):
     fields: List[FieldDefinition]
 
@@ -76,12 +82,8 @@ class StoredDataProductSchema(StoredSchemaBase):
     fields: List[FieldDefinition]
 
 
-class UpdateStreamingSchema(pydantic.BaseModel):
-    details: StreamingDataProductSchema
-
-
-class UpdateStoredSchema(pydantic.BaseModel):
-    details: StoredDataProductSchema
+class UpdateDataProductSchema(pydantic.BaseModel):
+    details: Union[StreamingDataProductSchema, StoredDataProductSchema] = pydantic.Field(..., discriminator="type")
 
 
 class RegisterCore(BaseModel):
