@@ -1,4 +1,3 @@
-import os
 import typing
 
 import httpx
@@ -24,9 +23,9 @@ def _secret_url(name: str, gateway_api_url: str) -> str:
 @app.command()
 def add_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     job_filepath: str = typer.Option(..., "--job-filepath", "-f", callback=util.sanitize),
@@ -41,7 +40,7 @@ def add_job(
     def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
         return util.post(
             ctx,
-            _spark_url(product_name, ctx.obj.gateway_api_url),
+            _spark_url(product_identifier, ctx.obj.gateway_api_url),
             files={"spark_file": f},
         )
 
@@ -56,9 +55,9 @@ def add_job(
 @app.command()
 def generate_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     json_filepath: str = typer.Option(..., "--json-filepath", "-f", callback=util.sanitize),
@@ -84,7 +83,7 @@ def generate_job(
     def _request(ctx: typer.Context, data: typing.Dict) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/generate",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/generate",
             json=data,
         )
 
@@ -101,9 +100,9 @@ def generate_job(
 @app.command()
 def fetch_job_preview(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -113,7 +112,7 @@ def fetch_job_preview(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/preview",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/preview",
         )
 
     r = _request(ctx)
@@ -124,9 +123,9 @@ def fetch_job_preview(
 @app.command()
 def job_history(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -136,7 +135,7 @@ def job_history(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/history",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/history",
         )
 
     r = _request(ctx)
@@ -147,9 +146,9 @@ def job_history(
 @app.command()
 def run_history(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     suffix: str = typer.Option(None, "--suffix", "-s", callback=util.sanitize),
@@ -161,7 +160,7 @@ def run_history(
         return util.get(
             ctx,
             "{spark_url}/history/{suffix}/run".format(
-                spark_url=_spark_url(product_name, ctx.obj.gateway_api_url),
+                spark_url=_spark_url(product_identifier, ctx.obj.gateway_api_url),
                 suffix=suffix,
             ),
         )
@@ -174,9 +173,9 @@ def run_history(
 @app.command()
 def job_status(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     suffix: str = typer.Option(None, "--suffix", "-s", callback=util.sanitize),
@@ -200,7 +199,7 @@ def job_status(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}",
             params=params,
         )
 
@@ -218,9 +217,9 @@ def _render_logs(payload: typing.Union[typing.Dict, typing.List]) -> str:
 @app.command()
 def job_logs(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     suffix: str = typer.Option(None, "--suffix", "-s", callback=util.sanitize),
@@ -244,7 +243,7 @@ def job_logs(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/log",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/log",
             params=params,
         )
 
@@ -256,9 +255,9 @@ def job_logs(
 @app.command()
 def update_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     job_filepath: str = typer.Option(None, "--job-filepath", "-f", callback=util.sanitize),
@@ -277,7 +276,7 @@ def update_job(
 
         return util.put(
             ctx,
-            _spark_url(product_name, ctx.obj.gateway_api_url),
+            _spark_url(product_identifier, ctx.obj.gateway_api_url),
             files=files,
         )
 
@@ -295,9 +294,9 @@ def update_job(
 @app.command()
 def remove_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     *,
@@ -313,7 +312,7 @@ def remove_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            _spark_url(product_name, ctx.obj.gateway_api_url),
+            _spark_url(product_identifier, ctx.obj.gateway_api_url),
             params={"force": force},
         )
 
@@ -324,9 +323,9 @@ def remove_job(
 @app.command()
 def trigger_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -339,7 +338,7 @@ def trigger_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/trigger",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/trigger",
         )
 
     r = _request(ctx)
@@ -349,9 +348,9 @@ def trigger_job(
 @app.command()
 def csv_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     delimiter: str = typer.Option(",", "--delimiter", "-d", help="csv delimiter", callback=util.sanitize),
@@ -390,7 +389,7 @@ def csv_job(
 
         return util.post(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/csv",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/csv",
             params=params,
             files={"csv_file": f},
         )
@@ -406,9 +405,9 @@ def csv_job(
 @app.command()
 def schedule_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     schedule: str = typer.Option(
@@ -428,7 +427,7 @@ def schedule_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/scheduled",
             json={
                 "cron_expression": schedule,
             },
@@ -441,9 +440,9 @@ def schedule_job(
 @app.command()
 def reschedule_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     schedule: str = typer.Option(
@@ -463,7 +462,7 @@ def reschedule_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.put(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/scheduled",
             json={
                 "cron_expression": schedule,
             },
@@ -476,9 +475,9 @@ def reschedule_job(
 @app.command()
 def unschedule_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -491,7 +490,7 @@ def unschedule_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/scheduled",
         )
 
     r = _request(ctx)
@@ -501,9 +500,9 @@ def unschedule_job(
 @app.command()
 def stream_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     trigger_interval: str = typer.Option(
@@ -524,7 +523,7 @@ def stream_job(
 
         return util.post(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/streaming",
             params=params,
         )
 
@@ -535,9 +534,9 @@ def stream_job(
 @app.command()
 def restream_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     trigger_interval: str = typer.Option(
@@ -558,7 +557,7 @@ def restream_job(
 
         return util.put(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/streaming",
             params=params,
         )
 
@@ -569,9 +568,9 @@ def restream_job(
 @app.command()
 def unstream_job(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -584,7 +583,7 @@ def unstream_job(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
+            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/streaming",
         )
 
     r = _request(ctx)
@@ -594,7 +593,7 @@ def unstream_job(
 @secret_app.command()
 def add(
     ctx: typer.Context,
-    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier"),
     secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
 ) -> None:
     """Add a set of secrets for a spark job."""
@@ -603,7 +602,7 @@ def add(
     def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
         return util.post(
             ctx,
-            _secret_url(product_name, ctx.obj.gateway_api_url),
+            _secret_url(product_identifier, ctx.obj.gateway_api_url),
             json=payload,
         )
 
@@ -620,7 +619,7 @@ def add(
 @secret_app.command()
 def update(
     ctx: typer.Context,
-    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    product_identifier: str = typer.Argument(..., help="Data Product identifier"),
     secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
 ) -> None:
     """Update existing secrets.
@@ -633,7 +632,7 @@ def update(
     def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
         return util.patch(
             ctx,
-            _secret_url(product_name, ctx.obj.gateway_api_url),
+            _secret_url(product_identifier, ctx.obj.gateway_api_url),
             json=payload,
         )
 
@@ -650,9 +649,9 @@ def update(
 @secret_app.command()
 def remove(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -662,7 +661,7 @@ def remove(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            _secret_url(product_name, ctx.obj.gateway_api_url),
+            _secret_url(product_identifier, ctx.obj.gateway_api_url),
         )
 
     r = _request(ctx)
@@ -673,9 +672,9 @@ def remove(
 @secret_app.command()
 def remove_key(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
     keys: typing.List[str] = typer.Option(
@@ -692,7 +691,7 @@ def remove_key(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            f"{_secret_url(product_name, ctx.obj.gateway_api_url)}/key",
+            f"{_secret_url(product_identifier, ctx.obj.gateway_api_url)}/key",
             json={"keys": keys},
         )
 
@@ -704,9 +703,9 @@ def remove_key(
 @secret_app.command()
 def get(
     ctx: typer.Context,
-    product_name: str = typer.Argument(
-        os.getenv("NEOSCTL_PRODUCT", ...),
-        help="Data Product name",
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
         callback=util.sanitize,
     ),
 ) -> None:
@@ -716,7 +715,7 @@ def get(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            _secret_url(product_name, ctx.obj.gateway_api_url),
+            _secret_url(product_identifier, ctx.obj.gateway_api_url),
         )
 
     r = _request(ctx)
